@@ -311,12 +311,14 @@ class AnsibleRunner:
         hostvars.setdefault("inventory_hostname", host)
         group_names = []
         groups = {}
+
         for group in sorted(inventory):
             if group == "_meta":
                 continue
             groups[group] = sorted(itergroup(inventory, group))
-            if group != "all" and host in inventory[group].get("hosts", []):
+            if host in groups[group]:
                 group_names.append(group)
+
         hostvars.setdefault("group_names", group_names)
         hostvars.setdefault("groups", groups)
         return hostvars
@@ -393,9 +395,7 @@ class AnsibleRunner:
                     "msg": "Skipped. You might want to try check=False",
                 }
             if not files:
-                raise RuntimeError(
-                    "Error while running {}: {}".format(" ".join(cmd), out)
-                )
+                raise RuntimeError(f"{out}")
             fpath = os.path.join(d, files[0])
             try:
                 with open(fpath, "r", encoding="ascii") as f:
